@@ -407,13 +407,11 @@ class ER:
             isDisjunct(bool): Are the elements of this relation disjunct?
         '''
         # Add "X is a Y" relation - a green inverted triangle from a superclass to multiple subclasses
-        print([type(subclassParam).__name__, subclassParam])
         if not isinstance(subclassParam, list):
             subClasses = [subclassParam]
         else:
             subClasses = subclassParam
 
-        print([type(subClasses).__name__, subClasses])
 
         if not self.has_node(superClassLabel):
             self.add_node(superClassLabel)
@@ -537,26 +535,28 @@ class ER:
             self.__add_obj_copy(n1)
             if self.debug: print(" ")
 
-    def compareNodes(self, otherGraph, label = "", node_type = NodeType.NOT_SPECIFIED, scores={}):
+    def compareNodes(self, otherGraph, label = "", node_type = NodeType.NOT_SPECIFIED, scores={}, debug=False):
+        if debug: debugging = True
+        else: debugging = self.debug
         dist = 0
-        if self.debug:
+        if debugging:
             print(" ¶ calculating distances between graphs:    ")
         if scores == {}:
-            if self.debug:
+            if debugging:
                 print("  no scores provided, fallback to default.")
             scores = self.get_default_scores()
         for n1 in self.get_obj(label, node_type = node_type):
-            if self.debug:
+            if debugging:
                 print(f" » testing {n1['label']}:")
             if not otherGraph.has_node(n1["label"]):
-                if self.debug:
+                if debugging:
                     print(f"   ✗ {scores['missing_node']:+.2f}, node '{n1['label']}' doesn't exist in other graph")
                 dist += scores['missing_node']
             else:
                 # node exists, check equality
                 n2 = otherGraph.get_obj(n1["label"], node_type)
                 if n1 == n2:
-                    if self.debug:
+                    if debugging:
                         print(f"   ✓  {0:.2f}, match@{n1['label']}")
                         print(f"   =  {dist:.2f}")
                     continue
@@ -564,14 +564,14 @@ class ER:
 
                 for k, v in n1.items():
                     if v != n2[k]:
-                        if self.debug:
+                        if debugging:
                             print(f"   ✗ {distancePerProperty:+.2f}, mismatch@{k}: {v} != {n2[k]} ")
                         dist += distancePerProperty
 
-            if self.debug:
+            if debugging:
                 print(f"   =  {dist:.2f}")
 
-        if self.debug:
+        if debugging:
             print(f" ---------------")
             print(f"   ∑  {dist:.2f}")        
         return dist
@@ -650,6 +650,9 @@ class ER:
 
     def get_node_count(self):
         return len(self.get_graph().nodes())
+
+    def get_obj_count(self, nodeType = NodeType.NOT_SPECIFIED):
+        return len(self.get_obj("", nodeType))
                     
     def get_graphViz(self):
         return self.graphViz
